function make_PSF, ng, xarb, yarb, PSF_model, PSF_gaussian, PSF_rad, PSF_mag, $
				sum_resid_f, fit_rad, status
;
;	creates a new PSF appropriate for the image location (xarb, yarb)
;	as based on the PSF_model functions.
;
;	returns the array of residuals
;
;	also returns the PSF gaussian parameters via PSF_gaussian
;	and the "psfmag" via PSF_mag
;
;	DPC	20080721
;		20081227	added status variable (0=OK, -1=fail)
;
;---------------------------------------------------------------------
;
;	PSF model functions are:
;
;		A. 2nd order with coefficients in the SFIT/MAX_DEGREE order:
;				k, y, y2, x, xy, x2
;		B. 1st order with coeffs
;				k, y, x
;		C. 0th order, with no coeffs
;
;---------------------------------------------------------------------
;
;	PSF_model structure is :
;
;gauss_fit = dblarr(5,0 or 3 or 6)					; gaussian term x SFIT kx term
;resid_fit = dblarr(nxypsf, nxypsf,0 or 3 or 6)
;;
;PSF_model = {	nxypsf: nxypsf, $
;				psfmag: psfmag, $
;				rad_psf: rad_psf, $
;				fit_rad: fit_rad, $
;				gauss_fit: gauss_fit, $
;				resid_fit: resid_fit $
;			 }
;
;----------------------------------------------------------------------
;
;	begin by computing the gaussian parameters
;
nxypsf = PSF_model.nxypsf
PSF_rad = double(PSF_model.rad_psf)
fit_rad = double(PSF_model.fit_rad)
x = double(xarb)
y = double(yarb)
;
xcen = float(nxypsf/2.)-0.5
ycen = xcen
;
resid = dblarr(nxypsf, nxypsf)
;
PSF_gaussian = dblarr(5)
;
for ig = 0, 4 do begin
	case ng of
		1: begin
			PSF_gaussian[ig] = PSF_model.gauss_fit[ig]
		   end
		2: begin
			PSF_gaussian[ig] = PSF_model.gauss_fit[ig,0] + PSF_model.gauss_fit[ig,1] * y $
					   + PSF_model.gauss_fit[ig,2] * x
		   end
		3: begin
			PSF_gaussian[ig] = PSF_model.gauss_fit[ig,0] + PSF_model.gauss_fit[ig,1] * y $
					   + PSF_model.gauss_fit[ig,2] * x
		   end
		else: begin
			PSF_gaussian[ig] = PSF_model.gauss_fit[ig,0] + PSF_model.gauss_fit[ig,1] * y $
					   + PSF_model.gauss_fit[ig,2] * (y * y) + PSF_model.gauss_fit[ig,3] * x $
					   + PSF_model.gauss_fit[ig,4] * x * y + PSF_model.gauss_fit[ig,5] * x * x
		   end
	endcase
endfor
;
;	create the gaussian representation
;
;gauss_array = dblarr(nxypsf, nxypsf)
;cen = FLOOR(Float(nxypsf) / 2.)				; index of the center x or y pixel, ref to 0
;;
;for ix = 0, nxypsf-1 do begin
;	x0 = float(ix - cen) - 0.5
;	for ixx = 0, 9 do begin					; 1/10th pixel steps
;		this_x = x0 + 0.1*ixx + 0.05
;		;
;		for iy = 0, nxypsf-1 do begin
;			y0 = float(iy - cen) - 0.5
;			for iyy = 0, 9 do begin
;				this_y = y0 + 0.1*iyy + 0.05
;				;
;				;	evaluate the gaussian here, then multiply by the area of 1/100 pixel
;				;
;				this_g = PSF_gaussian[0] * exp(-0.5*((this_x - PSF_gaussian[1])/PSF_gaussian[3])^2 $
;											   -0.5*((this_y - PSF_gaussian[2])/PSF_gaussian[4])^2)
;				gauss_array[ix,iy] += this_g / 100.0
;			endfor
;		endfor
;	endfor
;endfor
;
;	can view the gaussian here
;
;writefits, dialog_pickfile(title='Gaussian FIT file to save'),gauss_array
;
;	and all the residuals (and counts within psf_rad)
;
sum_resid_f = 0.0d0
;sum_resid_p = 0.0d0
for ix = 0, nxypsf-1 do begin
	for iy = 0, nxypsf-1 do begin
		case ng of
			1: begin
				resid[ix,iy] = PSF_model.resid_fit[ix,iy]
			   end
			2: begin
				 resid[ix,iy] = PSF_model.resid_fit[ix,iy,0] + PSF_model.resid_fit[ix,iy,1] * y $
					   + PSF_model.resid_fit[ix,iy,2] * x
			   end
			3: begin
				 resid[ix,iy] = PSF_model.resid_fit[ix,iy,0] + PSF_model.resid_fit[ix,iy,1] * y $
					   + PSF_model.resid_fit[ix,iy,2] * x
			   end
			else: begin
					resid[ix,iy] = PSF_model.resid_fit[ix,iy,0] + PSF_model.resid_fit[ix,iy,1] * y $
					   + PSF_model.resid_fit[ix,iy,2] * (y * y) + PSF_model.resid_fit[ix,iy,3] * x $
					   + PSF_model.resid_fit[ix,iy,4] * x * y + PSF_model.resid_fit[ix,iy,5] * x * x
                  end
        endcase
		dx = float(ix) - xcen
		dy = float(iy) - ycen
		rad = sqrt(dx * dx + dy * dy)/2.
		if(rad le fit_rad) then begin
			sum_resid_f = sum_resid_f + 0.25 * resid[ix,iy]
		endif
	endfor
endfor
;
;	next, compute psf mag from gaussian sum and resid sum
;
gauss_sum = PSF_gaussian[0] * !DPI * 2.0 * abs(PSF_gaussian[3] * PSF_gaussian[4])
;
total_counts = sum_resid_f + gauss_sum
;
PSF_mag = PSF_model.psfmag
;
if(NOT(FINITE(PSF_mag))) then begin
	print, "PSFMAG not finite in g_make_psf. Blowing up on purpose..."
	status = -1
	return, resid
endif
;
status=0
return, resid
;
end